summaryrefslogtreecommitdiffstats
path: root/winsup/cygwin/sigproc.h
diff options
context:
space:
mode:
Diffstat (limited to 'winsup/cygwin/sigproc.h')
-rw-r--r--winsup/cygwin/sigproc.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/winsup/cygwin/sigproc.h b/winsup/cygwin/sigproc.h
index 5a8e808fc..40f518777 100644
--- a/winsup/cygwin/sigproc.h
+++ b/winsup/cygwin/sigproc.h
@@ -20,7 +20,8 @@ enum procstuff
PROC_CHILDSTOPPED = 2, // a child stopped
PROC_CHILDTERMINATED = 3, // a child died
PROC_CLEARWAIT = 4, // clear all waits - signal arrived
- PROC_WAIT = 5 // setup for wait() for subproc
+ PROC_WAIT = 5, // setup for wait() for subproc
+ PROC_NOTHING = 6 // nothing, really
};
typedef struct struct_waitq